# pythonPackages

### Table of Contents

1. [Installation](#installation)
2. [Project Motivation](#motivation)
3. [File Descriptions](#files)
4. [Licensing, Authors, and Acknowledgements](#licensing)

## Installation <a name="installation"></a>
The project is created with Python.
The requierement for this project is as following:-
1.Python 2.7
2.Matplotlib

You can install this package by pip install distribution_pdf

## Project Motivation<a name="motivation"></a>
This project targets different type of distribution and displaying them graphically.
You can use the packages to analyze distribution and display.

## File Descriptions <a name="files"></a>
There is modular package distribution inside that all the working code is.
Application.py is an example file on how to use the package.
setup.py is the setup file for installation.
test.py file contains unittests.

## Licensing, Authors, Acknowledgements<a name="licensing"></a>
Separate LICENSE file is there with this project.
C@- Mukesh Regar